@@ -719,8 +719,15 @@ class Subscription(object):
 
             entry["metadata"]["date"] = str(audiofile.tag.getBestDate(prefer_recording_date=True))
 
-            audiofile.tag.save()
+            # TODO this is catching "Unable to write ID3 v2.2" error.
+            # should be able to do more gracefully.
+            try:
+                audiofile.tag.save()
+            except NotImplementedError as ef:
+                LOG.warning(f"Caught NotImplementedError {ef}. Skipping tag setting.")
+                return
 
+        # TODO this is catching tag not being present at all, I think, which should be fixable.
         except AttributeError as e:
             LOG.warning(f"Caught AttributeError {e}. Skipping tag setting.")
             return
